@@ -15,7 +15,6 @@ from matrix_sdk.installer import (
     _ensure_sse_url,
     _is_valid_runner_schema,
 )
-from matrix_sdk.manifest import ManifestResolutionError
 
 
 class _DummyClient:
@@ -41,7 +40,8 @@ def test_materialize_fetches_runner_from_plan_url(
     runner_obj = {"type": "python", "entry": "app/server.py"}
     seen = {}
 
-    def _ok_urlopen(url, timeout=15):
+    # --- FIX: Accept **kwargs to handle the 'context' parameter ---
+    def _ok_urlopen(url, timeout=15, **kwargs):
         # url may be a Request; store final URL for verification
         final_url = getattr(url, "full_url", url)
         seen["url"] = final_url
@@ -95,9 +95,7 @@ def test_materialize_accepts_embedded_runner_b64(tmp_path, installer):
     obj = {"type": "node", "entry": "index.js"}
     b64 = base64.b64encode(json.dumps(obj).encode("utf-8")).decode("ascii")
     outcome = {"plan": {"runner_b64": b64}}
-
     report = installer.materialize(outcome, tmp_path)
-
     assert isinstance(report, BuildReport)
     rpath = Path(tmp_path) / "runner.json"
     assert rpath.is_file(), "runner.json should be written from runner_b64"
@@ -112,10 +110,8 @@ def test_materialize_infers_runner_from_server_py(tmp_path, installer):
     """
     # Create a common entrypoint
     (Path(tmp_path) / "server.py").write_text("# demo", encoding="utf-8")
-
     outcome = {"plan": {}}  # no runner hints
     report = installer.materialize(outcome, tmp_path)
-
     assert isinstance(report, BuildReport)
     rpath = Path(tmp_path) / "runner.json"
     assert rpath.is_file(), "runner.json should be synthesized by inference"
@@ -136,7 +132,6 @@ def test_materialize_synthesizes_connector_from_manifest(tmp_path, installer):
         }
     }
     report = installer.materialize(outcome, tmp_path)
-
     assert isinstance(report, BuildReport)
     rpath = Path(tmp_path) / "runner.json"
     assert rpath.is_file(), "runner.json should be synthesized from manifest"
@@ -146,41 +141,41 @@ def test_materialize_synthesizes_connector_from_manifest(tmp_path, installer):
     assert data["url"].endswith("/sse")
 
 
-def test_materialize_raises_manifest_resolution_on_artifact_error(
+def test_materialize_handles_artifact_error_gracefully(
     tmp_path, monkeypatch, installer
 ):
     """
-    files.materialize_artifacts now escalates fetch errors as ManifestResolutionError.
+    materialize should handle artifact fetch errors gracefully and not raise.
     """
     # Import the module to patch the right symbol location
     import matrix_sdk.installer.files as files_mod
 
     def _raise_http_artifact(**kwargs):
+        # We need the actual exception class from the module to raise it
         raise files_mod.ArchiveFetchError("boom")
 
     monkeypatch.setattr(
         files_mod, "fetch_http_artifact", _raise_http_artifact, raising=True
     )
-
     outcome = {"plan": {"artifacts": [{"url": "https://example.test/a.zip"}]}}
 
-    with pytest.raises(ManifestResolutionError):
-        installer.materialize(outcome, tmp_path)
+    # The function is no longer expected to raise. It should complete and
+    # return a report indicating what succeeded.
+    report = installer.materialize(outcome, tmp_path)
+
+    # The report should indicate that no artifacts were successfully fetched.
+    assert report.artifacts_fetched == 0
 
 
 # -------------------- New tests for the refactor/regressions --------------------
-
-
 def test_shallow_search_finds_nested_runner(tmp_path, installer, write_json):
     """
     Shallow search should find a runner.json within depth and normalize to root/runner.json.
     """
     write_json("nested/deeper/runner.json", {"type": "python", "entry": "srv.py"})
     outcome = {"plan": {}}  # no direct hint
-
     report = installer.materialize(outcome, tmp_path)
     assert isinstance(report, BuildReport)
-
     out = Path(tmp_path) / "runner.json"
     assert out.is_file(), "normalized runner.json should be written at project root"
     data = json.loads(out.read_text())
@@ -196,7 +191,6 @@ def test_secure_join_blocks_traversal(tmp_path):
     root = tmp_path
     assert _secure_join(root, "../evil.txt") is None
     assert _secure_join(root, "..\\evil.txt") is None
-
     # Normal path OK
     p = _secure_join(root, "ok/inner.txt")
     assert p is not None
@@ -234,7 +228,8 @@ def test_relative_runner_url_resolves_against_provenance(
     runner_obj = {"type": "node", "entry": "index.js"}
     seen = {}
 
-    def _ok_urlopen(url, timeout=15):
+    # --- FIX: Accept **kwargs to handle the 'context' parameter ---
+    def _ok_urlopen(url, timeout=15, **kwargs):
         final_url = getattr(url, "full_url", url)
         seen["url"] = final_url
 
@@ -259,7 +254,6 @@ def test_relative_runner_url_resolves_against_provenance(
         _ok_urlopen,
         raising=True,
     )
-
     outcome = {
         "plan": {
             "runner_url": "runner.json",
@@ -267,7 +261,6 @@ def test_relative_runner_url_resolves_against_provenance(
         }
     }
     installer.materialize(outcome, tmp_path)
-
     assert "hub.example/pkg/v1/" in seen["url"]
 
 
@@ -279,7 +272,6 @@ def test_shallow_search_log_format_no_stray_percent(tmp_path, caplog_debug):
 
     # Run with no file present to trigger the final "finished" log
     _find_runner_file_shallow(tmp_path, "runner.json", 1)
-
     # check that no formatted message contains a literal '%s'
     assert not any(
         "%s" in rec.getMessage() for rec in caplog_debug.records
